<?php
// Automatically generated on [[regtime]]

/* 
 * Define multisites here. You **MUST EXPLICITLY** define all domains (including with or without www).
 * If you want to enable all sites pointing to a certain subsite, use the wildcard. Only one wildcard is allowed.*/

global $SchlixWebsites;

$SchlixWebsites =array (
  '[[domhost]]' => '[[site_id]]',
);